## telemetrix-rpi-pico-2w

# Telemetrix For The Raspberry Pi Pico 2W


This Python package allows you to monitor and control a Raspberry Pi Pico 2W 
board by 
simply writing a Python script using one of the telemetrix-rpi-pico-2w APIs.
APIs are provided for both synchronous and asyncio implementations for BLE, 
WiFi, and USB/Serial transports.

Please refer to the [User's Guide](https://mryslab.github.io/telemetrix-rpi-pico-2w/) for 
further information, including installation 
instructions and client APIs.

| Supported Features                 |
|------------------------------------|
| Analog Input                       |
| Analog Output (PWM)                |
| Digital Input                      |
| Digital Output                     |
| i2c Primitives                     |
| Servo Motor Control                |
| DHT Temperature/Humidity Sensor    |
| HC-SR04 Sonar Distance Sensor      |
| SPI Primitives                     |
| NeoPixel Control                   |
| Integrated Debugging Aids Provided |
| Examples Provided For All Features |



If you wish to extend Telemetrix's capabilities, a tutorial on how to do so is [available](https://mryslab.github.io/bits-n-bots/2025/05/20/telemetrix-under-the-hood--part-1/).


Programmed with [Pycharm](https://www.jetbrains.com/pycharm/)  ![](https://resources.jetbrains.com/storage/products/company/brand/logos/PyCharm_icon.svg)